indicio
Indicio provides a framework for emitting clues that may be used for debugging.
Status
Active development. Indicio is likely to change in the near future in backwards-incompatible ways.
Scope
Indicio will provide the interface for publishing clues and to the thread-local emitter.
Warts
- Currently it’s under-tested, so may be ugly.
Documentation
The latest documentation is always available at docs.rs.
Modules
Macros
- Emit the specified value if and only if the collector is logging.
- Match a “shape” of a clue and flatten it.
- Construct a value literal using something that looks like rust literals.
Structs
- A collector is meant to be a static singleton that conditionally logs.
- An emitter that filters log messages above a log level.
Enums
Constants
Traits
- An emitter for indicio that emits values.
Functions
- Registers this crate’s biometrics with the provided Collector.
- Registers this crate’s monitors with the provided HeyListen.