pub struct MapEntry { /* private fields */ }Trait Implementations
Sourceimpl<'prototk> FieldPackHelper<'prototk, message<MapEntry>> for MapEntry
impl<'prototk> FieldPackHelper<'prototk, message<MapEntry>> for MapEntry
Sourcefn field_pack_sz(&self, tag: &Tag) -> usize
fn field_pack_sz(&self, tag: &Tag) -> usize
The size of encoding self with tag.
Sourcefn field_pack(&self, tag: &Tag, out: &mut [u8])
fn field_pack(&self, tag: &Tag, out: &mut [u8])
Pack the tag into the output buffer.
Sourceimpl<'prototk> FieldUnpackHelper<'prototk, message<MapEntry>> for MapEntry
impl<'prototk> FieldUnpackHelper<'prototk, message<MapEntry>> for MapEntry
Sourcefn merge_field(&mut self, proto: message<MapEntry>)
fn merge_field(&mut self, proto: message<MapEntry>)
Merge the proto into self.
Sourceimpl Packable for MapEntry
impl Packable for MapEntry
Sourcefn pack_sz(&self) -> usize
fn pack_sz(&self) -> usize
pack_sz returns the number of bytes required to serialize the Packable object.Sourcefn pack(&self, buf: &mut [u8])
fn pack(&self, buf: &mut [u8])
pack fills in the buffer out with the packed binary representation of the Packable
object. The implementor is responsible to ensure that out is exactly pack_sz() bytes
and implementations are encouraged to assert this. Read moreSourcefn stream<W: Write>(&self, writer: &mut W) -> Result<usize, Error>
fn stream<W: Write>(&self, writer: &mut W) -> Result<usize, Error>
stream writes the object to the provided writer using the same representation that would
be used in a call to pack. The implementor is responsible for making sure that the
number of bytes written is exactly equal to the number of required bytes. Read moreSourceimpl<'prototk> Unpackable<'prototk> for MapEntry
impl<'prototk> Unpackable<'prototk> for MapEntry
impl Eq for MapEntry
impl<'prototk> Message<'prototk> for MapEntry
impl StructuralPartialEq for MapEntry